import { AxiosResponse, AxiosRequestConfig } from 'axios';

type RequestConfig = {
    /** 请求key */
    pendKey?: string;
    /** 不否使用缓存 */
    isNoCache?: boolean;
} & AxiosRequestConfig;
interface IOptions {
    /** 节流时间-时间毫秒内连续的相同请求会取缓存的数据返回给业务侧 */
    throttlingTime: number;
    /** 忽略的请求地址 */
    ignoreRequest: (string | RegExp)[];
}
/** 接口请求缓存-阻止重复请求 */
declare function optimizationCacheReq(config: RequestConfig): Promise<RequestConfig | undefined>;
/** 接口响应成功 */
declare function optimizationCacheSuccessRes(response: AxiosResponse<any, any> & {
    config: RequestConfig;
}): void;
/** 接口响应失败 */
declare function optimizationCacheErrorsRes(error: {
    config: RequestConfig;
    type: 'Success' | 'Error';
    val: any;
}): Promise<any>;
declare function isRegExp(v: any): boolean;
/** 初始化方法 */
declare function useOptimizationCache(options?: IOptions): {
    optimizationCacheReq: typeof optimizationCacheReq;
    optimizationCacheSuccessRes: typeof optimizationCacheSuccessRes;
    optimizationCacheErrorsRes: typeof optimizationCacheErrorsRes;
};

export { isRegExp, optimizationCacheErrorsRes, optimizationCacheReq, optimizationCacheSuccessRes, useOptimizationCache };
